// ---------------------------------------------------------------------------
// custom_weapons.cs -- Version 4.2 -- October 28, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Assign up to four weapons to any key
//
// For each key, you can specify:
//
//     (1) a preferred weapon to use on a single keypress,
//     (2) an alternate weapon if that one isn't available,
//     (3) a preferred weapon to use on a double keypress, and
//     (4) an alternate weapon if that one isn't available.
//
//     The script will use the first weapon that you are actually
//     carrying, so if neither of the "single keypress" weapons
//     are carried, it will look for (3), and if that isn't
//     carried, it will try (4). Similarly, if you "double press"
//     the key and neither of the double keypress weapons are
//     carried, the script will look for (1), then (2).
//
//     These settings are saved in configcustom_weapons_data.cs
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\custom_weapons.cs", "4.2", "Lorne Laliberte", "Oct 28, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");
include("writer\\save.cs");
include("writer\\screensize.cs");
include("writer\\whud.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_custom_weapons.cs file

    // Time in seconds within which you must press a key again
    // for it to be considered a "double press" of that key
    $WeaponKey::DoublePressTime = "0.3";

    // Coordinates for the weapon assignment mode hud
    $WeaponKeyHUD::x = "50%";
    $WeaponKeyHUD::y = "20%";

    // NOTE: If you use the number keys to access weapons, you can assign the
    //       original Tribes key config to those weapons for custom_weapons.cs
    //       by performing the following 5 steps:
    //
    //    1. Start Tribes
    //    2. Access console mode by pressing the ~ key
    //    3. type:  UseTribesKeys();
    //    4. Press enter
    //    5. Exit console mode by pressing the ~ key again
    //
    //       This sets the preferred weapon for each key from 1 to 9 to match
    //       the original Tribes weapon for that key.
    //
    //       Those of you who still use the original Tribes weapon key config
    //       can use this to start running custom_weapons.cs without having to
    //       do any weapon key assigning in-game.

    // Bind the weapon keys
    //
    // The syntax is:
    //
    // WeaponKey::bind(<device>, [<modifier>,] [<modifier>,] [<modifier>,] <key>);
    //
    // Examples:  WeaponKey::bind(keyboard0, "1");
    //            WeaponKey::bind(keyboard0, l_shift, "q");
    //            WeaponKey::bind(mouse0, shift, "button2");

    WeaponKey::bind(keyboard0, "1");
    WeaponKey::bind(keyboard0, "2");
    WeaponKey::bind(keyboard0, "3");
    WeaponKey::bind(keyboard0, "4");
    WeaponKey::bind(keyboard0, "5");
    WeaponKey::bind(keyboard0, "6");
    WeaponKey::bind(keyboard0, "7");
    WeaponKey::bind(keyboard0, "8");
    WeaponKey::bind(keyboard0, "9");
    WeaponKey::bind(keyboard0, "0");

    // Enter Preferred Weapon Key Assignment Mode
    //bind(keyboard0, make, alt, "9", to, "WeaponKey::AssignMode(1);");
    //bind(keyboard0, break, alt, "9", to, "", "WeaponKey::AssignMode_preferred_break");

    // Enter Backup Weapon Key Assignment Mode
    //bind(keyboard0, make, alt, "0", to, "WeaponKey::AssignMode(2);");
    //bind(keyboard0, break, alt, "0", to, "", "WeaponKey::AssignMode_backup_break");

// ---------------------------------------------------------------------------

WriterPrefs::load("custom_weapons");

$WeaponKeyHUD::width = 480;
$WeaponKeyHUD::height = 174;

$WeaponKey::list::count += 0;


// In order to save the data we need to remember what keys are being used
//
function WeaponKey::add(%device, %m1, %m2, %m3, %key)
{
    if($WeaponKey::exists[%device, %m1, %m2, %m3, %key])
        return;

    $WeaponKey::exists[%device, %m1, %m2, %m3, %key] = true;

    $WeaponKey::list::count++;

    $WeaponKey::list::device[$WeaponKey::list::count] = %device;
    $WeaponKey::list::m1[$WeaponKey::list::count] = %m1;
    $WeaponKey::list::m2[$WeaponKey::list::count] = %m2;
    $WeaponKey::list::m3[$WeaponKey::list::count] = %m3;
    $WeaponKey::list::key[$WeaponKey::list::count] = %key;
}

// Assign weapon to single or double press of given key
//
function WeaponKey::assign(%device, %m1, %m2, %m3, %key)
{
    if($WeaponKey::double_typed[%device, %m1, %m2, %m3, %key])
    {
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 2] = $Inv::Name[getMountedItem(0)];
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 0] = $WeaponKey::temp[%device, %m1, %m2, %m3, %key, 0];
    }
    else
    {
        $WeaponKey::temp[%device, %m1, %m2, %m3, %key, 0] = $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 0];
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 0] = $Inv::Name[getMountedItem(0)];
    }


    %keystr = "";

    if(String::Compare(%m1, ""))
        %keystr = %m1 @ "-";

    if(String::Compare(%m2, ""))
        %keystr = %keystr @ %m2 @ "-";

    if(String::Compare(%m3, ""))
        %keystr = %keystr @ %m3 @ "-";

    %keystr = %keystr @ %key;

    %text = "<f0><L5>Weapon Key\t<f2>" @ %keystr @ "<f0>  -\t\t<f1> SINGLE<f0>\tPRESS\t\t\t\t\t\t-  <f1>" @ $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 0]
        @ "\n<f0><L5>Weapon Key\t<f2>" @ %keystr @ "<f0>  -\t\t<f1>DOUBLE<f0>\tPRESS\t\t\t\t\t\t-  <f1>" @ $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 2] @"<f0>";

    remoteBP(2048, %text, 5);
    WeaponKey::add(%device, %m1, %m2, %m3, %key);
}


// Assign alternate (backup) weapon for single or double press of given key
//
function WeaponKey::assignAlternate(%device, %m1, %m2, %m3, %key)
{
    if($WeaponKey::double_typed[%device, %m1, %m2, %m3, %key])
    {
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 3] = $Inv::Name[getMountedItem(0)];
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 1] = $WeaponKey::temp[%device, %m1, %m2, %m3, %key, 1];
    }
    else
    {
        $WeaponKey::temp[%device, %m1, %m2, %m3, %key, 1] = $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 1];
        $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 1] = $Inv::Name[getMountedItem(0)];
    }

    %keystr = "";

    if(String::Compare(%m1, ""))
        %keystr = %m1 @ "-";

    if(String::Compare(%m2, ""))
        %keystr = %keystr @ %m2 @ "-";

    if(String::Compare(%m3, ""))
        %keystr = %keystr @ %m3 @ "-";

    %keystr = %keystr @ %key;

    %text = "<f0><L5>Weapon Key\t<f2>" @ %keystr @ "<f0>  -\t\t<f1> SINGLE<f0>\tPRESS <f0>BACKUP<f0> \t\t-  <f1>" @ $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 1]
        @ "\n<f0><L5>Weapon Key\t<f2>" @ %keystr @ "<f0>  -\t\t<f1>DOUBLE<f0>\tPRESS <f0>BACKUP<f0> \t\t-  <f1>" @ $WeaponKey::weapon[%device, %m1, %m2, %m3, %key, 3] @"<f0>";

    remoteBP(2048, %text, 5);
    WeaponKey::add(%device, %m1, %m2, %m3, %key);
}


// Switch to the first available of four weapons, starting
// with the first weapon on a single key press, or the third
// weapon on a double key press, in this order:
//
//      SINGLE KEYPRESS:           DOUBLE KEYPRESS
//
//  1   Single Keypress Weapon     Double Keypress Weapon
//  2   Single Keypress Backup     Double Keypress Backup
//  3   Double Keypress Weapon     Single Keypress Weapon
//  4   Double Keypress Backup     Single Keypress Backup
//
function WeaponKey::make(%device, %m1, %m2, %m3, %key)
{
    if(!$WeaponKey::AssignMode)
    {
        // Interrupt a middle mouse button repair if we're doing one
        if($MMB::Repairing)
            MMB::StopRepair();

        %weapon = 0; // check for single keypress weapons by default
        if($WeaponKey::double_typed[%device, %m1, %m2, %m3, %key])
        {
            // Check for double keypress weapons first
            %weapon = 2;
        }

        for(%i = 0; %i < 4; %i++)
        {
            if(%weapon > 3)
                %weapon = 0;

            if( getItemCount($WeaponKey::weapon[%device, %m1, %m2, %m3, %key, %weapon]) )
            {
                // We're carrying this weapon

                if(WeaponKey::AmmoCheck($WeaponKey::weapon[%device, %m1, %m2, %m3, %key, %weapon]))
                {
                    // Use the weapon
                    use($WeaponKey::weapon[%device, %m1, %m2, %m3, %key, %weapon]);

                    break; // exit loop
                }
            }
            %weapon++;
        }
        return;
    }

    // We're in AssignMode
    if($WeaponKey::AssignMode == 1)
        WeaponKey::assign(%device, %m1, %m2, %m3, %key);
    else if($WeaponKey::AssignMode == 2)
        WeaponKey::assignAlternate(%device, %m1, %m2, %m3, %key);
}


// Return true if weapon has any ammo left (or doesn't need any)
//
function WeaponKey::AmmoCheck(%weapon)
{
    %ammo = $Inv::Ammo[%weapon];
    return (%ammo == "") || getItemCount(%ammo);
}


// Call this on the key break to start the double-type timer
//
function WeaponKey::break(%device, %m1, %m2, %m3, %key)
{
    $WeaponKey::double_typed[%device, %m1, %m2, %m3, %key] = 1;
    schedule::add("$WeaponKey::double_typed[" @ %device @ ", \"" @ escapestring(%m1) @ "\",\"" @ %m2 @ "\",\"" @ %m3 @ "\",\"" @ escapestring(%key) @ "\"]=0;", $WeaponKey::DoublePressTime, weaponkey_double_typed);
}


function WeaponKey::save()
{
    $WeaponKey::AssignMode = 0;
    popActionMap("weaponkeyMap.sae");
    whud::remove(weaponkeyHUD);

    echo("Weapon Key Assignment Mode exited -- saving new settings.");
    WeaponKey::saveData();
}


function WeaponKey::cancel()
{
    $WeaponKey::AssignMode = 0;
    popActionMap("weaponkeyMap.sae");
    whud::remove(weaponkeyHUD);

    echo("Weapon Key Assignment Mode cancelled -- reverting to previous settings.");
    WeaponKey::init();
}


function WeaponKey::AssignMode(%mode)
{
    if($WeaponKey::Assignmode)
        return;

    $WeaponKey::AssignMode = %mode;

    if(%mode == 1) // assign preferred weapon
    {
        NewActionMap("weaponkeyMap.sae");

        bindCommand(keyboard0, make, "enter", TO, "WeaponKey::save();");
        bindCommand(keyboard0, break, "enter", TO, "");

        bindCommand(keyboard0, make, "escape", TO, "WeaponKey::cancel();");
        bindCommand(keyboard0, break, "escape", TO, "");

        pushActionMap("weaponkeyMap.sae");

        %text = "<f1><L5>Preferred Weapon Assignment Mode\n\n" @
                    "<f0>(Preferred Weapons override Alternate Weapons for a given key\n" @
                        "whenever you are carrying both weapons.)\n\n" @
                    "<f0>Press a key to assign the currently mounted weapon to that key.\n" @
                        "(Double-press to assign to the double-press of that key.)\n\n" @
                        "Use your nextWeapon key to change weapons at any time.\n\n" @
                    "<f1>When you're done assigning weapons to keys, press <f2>Enter<f1> to save\n" @
                        "your changes, or <f2>Esc<f1> to cancel them.";

        wHUD::make(weaponkeyHUD, $WeaponKeyHud::x, $WeaponKeyHud::y, $WeaponKeyHUD::width, $WeaponKeyHUD::height, 0, 1, %text, "", 6);

    }
    else if(%mode == 2) // assign backup weapon
    {
        NewActionMap("weaponkeyMap.sae");
        bindCommand(keyboard0, make, "enter", TO, "WeaponKey::save();");
        bindCommand(keyboard0, break, "enter", TO, "");

        bindCommand(keyboard0, make, "escape", TO, "WeaponKey::cancel();");
        bindCommand(keyboard0, break, "escape", TO, "");

        pushActionMap("weaponkeyMap.sae");

        %text = "<f1><L5>Alternate Weapon Assignment Mode\n\n" @
                    "<f0>(Alternate Weapons are used when you aren't carrying the\n" @
                        "Preferred Weapon for that key.)\n\n" @
                    "<f0>Press a key to assign the currently mounted weapon to that key.\n" @
                        "(Double-press to assign to the double-press of that key.)\n\n" @
                        "Use your nextWeapon key to change weapons at any time.\n\n" @
                    "<f1>When you're done assigning weapons to keys, press <f2>Enter<f1> to save\n" @
                        "your changes, or <f2>Esc<f1> to cancel them.";

        wHUD::make(weaponkeyHUD, $WeaponKeyHud::x, $WeaponKeyHud::y, $WeaponKeyHUD::width, $WeaponKeyHUD::height, 0, 1, %text, "", 6);
    }
}


// Superimpose the Original Tribes weapon key config
// over the current weaponkey config
function UseTribesKeys()
{
    WeaponKey::add(keyboard0, "", "", "", "1");
    WeaponKey::add(keyboard0, "", "", "", "2");
    WeaponKey::add(keyboard0, "", "", "", "3");
    WeaponKey::add(keyboard0, "", "", "", "4");
    WeaponKey::add(keyboard0, "", "", "", "5");
    WeaponKey::add(keyboard0, "", "", "", "6");
    WeaponKey::add(keyboard0, "", "", "", "7");
    WeaponKey::add(keyboard0, "", "", "", "8");
    WeaponKey::add(keyboard0, "", "", "", "9");

    $WeaponKey::weapon[keyboard0, "", "", "", "1", 0] = "Blaster";
    $WeaponKey::weapon[keyboard0, "", "", "", "2", 0] = "Plasma Gun";
    $WeaponKey::weapon[keyboard0, "", "", "", "3", 0] = "Chaingun";
    $WeaponKey::weapon[keyboard0, "", "", "", "4", 0] = "Disc Launcher";
    $WeaponKey::weapon[keyboard0, "", "", "", "5", 0] = "Grenade Launcher";
    $WeaponKey::weapon[keyboard0, "", "", "", "6", 0] = "Laser Rifle";
    $WeaponKey::weapon[keyboard0, "", "", "", "7", 0] = "ELF Gun";
    $WeaponKey::weapon[keyboard0, "", "", "", "8", 0] = "Mortar";
    $WeaponKey::weapon[keyboard0, "", "", "", "9", 0] = "Targeting Laser";

    WeaponKey::saveData();
}


function WeaponKey::saveData()
{
    flushExportText();
    newObject(weaponkeySave, fearguiformattedtext,0,0,0,0);

    AddExportText("// ---------------------------------------------------------------------------");
    AddExportText("// custom_weapons_data.cs -- Version 1.3 -- April 10, 2000");
    AddExportText("// by Lorne Laliberte (writer@planetstarsiege.com)");
    AddExportText("//");
    AddExportText("// http://www.writerscripts.com");
    AddExportText("// ---------------------------------------------------------------------------");
    AddExportText("");
    AddExportText("// The format is:");
    AddExportText("//");
    AddExportText("//     WeaponKey::add(<device>, <modifier1>, <modfier2>, <modifier3>, <key>);");
    AddExportText("// $WeaponKey::weapon[<device>, <modifier1>, <modfier2>, <modifier3>, <key>, 0] = <preferred weapon for single key press>");
    AddExportText("// $WeaponKey::weapon[<device>, <modifier1>, <modfier2>, <modifier3>, <key>, 1] = <alternate weapon for single key press>");
    AddExportText("// $WeaponKey::weapon[<device>, <modifier1>, <modfier2>, <modifier3>, <key>, 2] = <preferred weapon for double key press>");
    AddExportText("// $WeaponKey::weapon[<device>, <modifier1>, <modfier2>, <modifier3>, <key>, 3] = <alternate weapon for double key press>");
    AddExportText("");
    AddExportText("");

    %padding = "                                                                 ";
    for(%i = 1; %i <= $WeaponKey::list::count; %i++)
    {
        AddExportText("     WeaponKey::add(\"" @              $WeaponKey::list::device[%i]     @ "\", "
                                        @ "\"" @ escapestring($WeaponKey::list::modifier1[%i]) @ "\", "
                                        @ "\"" @              $WeaponKey::list::modifier2[%i]  @ "\", "
                                        @ "\"" @              $WeaponKey::list::modifier3[%i]  @ "\", "
                                        @ "\"" @ escapestring($WeaponKey::list::key[%i])       @ "\");");

        %longest = 0;
        for(%t = 0; %t < 4; %t++)
        {
            %line[%t] = "$WeaponKey::weapon[\"" @              $WeaponKey::list::device[%i]     @ "\", "
                                         @ "\"" @ escapestring($WeaponKey::list::modifier1[%i]) @ "\", "
                                         @ "\"" @              $WeaponKey::list::modifier2[%i]  @ "\", "
                                         @ "\"" @              $WeaponKey::list::modifier3[%i]  @ "\", "
                                         @ "\"" @ escapestring($WeaponKey::list::key[%i])       @ "\", "
                                                @ %t @ "] = "
                                         @ "\"" @ escapestring($WeaponKey::weapon[$WeaponKey::list::device[%i],
                                                                                  $WeaponKey::list::modifier1[%i],
                                                                                  $WeaponKey::list::modifier2[%i],
                                                                                  $WeaponKey::list::modifier3[%i],
                                                                                  $WeaponKey::list::key[%i], %t]) @ "\";";

            // calculate the length of this line
            %len[%t] = 0;
            while(String::getSubStr(%line[%t], %len[%t], 1) != "") %len[%t]++;

            if(%len[%t] > %longest)
                %longest = %len[%t];
        }

        AddExportText(%line[0] @ String::getSubStr(%padding, 0, %longest - %len0) @ " // single-keypress preferred");
        AddExportText(%line[1] @ String::getSubStr(%padding, 0, %longest - %len1) @ " // single-keypress alternate");
        AddExportText(%line[2] @ String::getSubStr(%padding, 0, %longest - %len2) @ " // double-keypress preferred");
        AddExportText(%line[3] @ String::getSubStr(%padding, 0, %longest - %len3) @ " // single-keypress alternate");
        AddExportText("");
    }

    AddExportText("// Remove the weaponkeySave object that gets created whenever this file is executed");
    AddExportText("if(isObject(weaponkeySave))");
    AddExportText("    deleteobject(weaponkeySave);");

    exportObjectToScript(WeaponKeySave, "config\\custom_weapons_data.cs", true);
    deleteobject(weaponkeySave);
    flushExportText();

    echo();
    echo("config\\custom_weapons_data.cs saved!");
    echo();
}

function custom_weapons::save()
{
    AddExportText("    // Time in seconds within which you must press a key again");
    AddExportText("    // for it to be considered a \"double press\" of that key");
    ExportSetting("    $WeaponKey::DoublePressTime", "0.3");
    AddExportText("");
    AddExportText("    // Coordinates for the weapon assignment mode hud");
    ExportSetting("    $WeaponKeyHUD::x", "50%");
    ExportSetting("    $WeaponKeyHUD::y", "20%");
    AddExportText("");
    AddExportText("    // NOTE: If you use the number keys to access weapons, you can assign the");
    AddExportText("    //       original Tribes key config to those weapons for custom_weapons.cs");
    AddExportText("    //       by performing the following 5 steps:");
    AddExportText("    //");
    AddExportText("    //    1. Start Tribes");
    AddExportText("    //    2. Access console mode by pressing the ~ key");
    AddExportText("    //    3. type:  UseTribesKeys();");
    AddExportText("    //    4. Press enter");
    AddExportText("    //    5. Exit console mode by pressing the ~ key again");
    AddExportText("    //");
    AddExportText("    //       This sets the preferred weapon for each key from 1 to 9 to match");
    AddExportText("    //       the original Tribes weapon for that key.");
    AddExportText("    //");
    AddExportText("    //       Those of you who still use the original Tribes weapon key config");
    AddExportText("    //       can use this to start running custom_weapons.cs without having to");
    AddExportText("    //       do any weapon key assigning in-game.");
    AddExportText("");
    AddExportText("    // Bind the weapon keys");
    AddExportText("    //");
    AddExportText("    // The syntax is:");
    AddExportText("    //");
    AddExportText("    // WeaponKey::bind(<device>, [<modifier>,] [<modifier>,] [<modifier>,] <key>);");
    AddExportText("    //");
    AddExportText("    // Examples:  WeaponKey::bind(keyboard0, \"1\");");
    AddExportText("    //            WeaponKey::bind(keyboard0, l_shift, \"q\");");
    AddExportText("    //            WeaponKey::bind(mouse0, shift, \"button2\");");
    AddExportText("");

    if($WeaponKey::list::count)
    {
        for(%i = 1; %i <= $WeaponKey::list::count; %i++)
        {
            %text = "    WeaponKey::bind(" @ $WeaponKey::list::device[%i] @ ", ";

            if(String::Compare($WeaponKey::list::modifier1[%i], "")) // $WeaponKey::list::modifier1[%i] != ""
                %text = %text @ "\"" @ escapestring($WeaponKey::list::modifier1[%i]) @ "\", ";

            if(String::Compare($WeaponKey::list::modifier2[%i], "")) // $WeaponKey::list::modifier2[%i] != ""
                %text = %text @ "\"" @ $WeaponKey::list::modifier2[%i] @ "\", ";

            if(String::Compare($WeaponKey::list::modifier3[%i], "")) // $WeaponKey::list::modifier3[%i] != ""
                %text = %text @ "\"" @ $WeaponKey::list::modifier3[%i] @ "\", ";

            %text = %text @ "\"" @ escapestring($WeaponKey::list::key[%i]) @ "\");";

            AddExportText(%text);
        }
    }
    else
    {
        AddExportText("    // Remove the // from each WeaponKey::bind() call");
        AddExportText("    // and edit the keys to suit your config.");
        AddExportText("");
        AddExportText("    //WeaponKey::bind(keyboard0, \"1\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"2\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"3\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"4\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"5\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"6\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"7\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"8\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"9\");");
        AddExportText("    //WeaponKey::bind(keyboard0, \"0\");");
    }

    AddExportText("");
    AddExportText("    // Enter Preferred Weapon Key Assignment Mode");
    ExportBind("WeaponKey::AssignMode(1);", "//bind(keyboard0, make, alt, \"9\", TO, \"WeaponKey::AssignMode(1);\");");
    ExportBind("WeaponKey::AssignMode_preferred_break", "//bind(keyboard0, break, alt, \"9\", TO, \"\", WeaponKey::AssignMode_preferred_break);");
    AddExportText("");
    AddExportText("    // Enter Backup Weapon Key Assignment Mode");
    ExportBind("WeaponKey::AssignMode(2);", "//bind(keyboard0, make, alt, \"0\", TO, \"WeaponKey::AssignMode(2);\");");
    ExportBind("WeaponKey::AssignMode_backup_break", "//bind(keyboard0, break, alt, \"0\", TO, \"\", WeaponKey::AssignMode_backup_break);");
}

WriterPrefs::save("custom_weapons");

function custom_weapons::init()
{
    needs("writer\\custom_weapons.cs", "writer\\event.cs 2.7",
                                       "writer\\screensize.cs 1.1",
                                       "writer\\inventory.cs 3.3",
                                       "writer\\item_events.cs 2.12",
                                       "writer\\save.cs 2.3",
                                       "writer\\screensize.cs 1.1",
                                       "writer\\whud.cs 1.2");

    if(isFile("config\\custom_weapons_data.cs"))
    {
        exec("custom_weapons_data.cs");
    }
    else
    {
        // create default custom_weapons_data.cs
        exec("writer\\custom_weapons_defaults.cs");
        WeaponKey::saveData();
    }
}
Event::Attach(writerInit, "custom_weapons::init();");

if(!$UsingWriterLoader) custom_weapons::init();
